Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: webkit/glue/cpp_variant.cc

Issue 3386009: Fix a problem that text prefs is not hooked up with CrosSettings. (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: fix missing Get calls by bumping up the limit Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/resources/options.html ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/cpp_variant.cc
diff --git a/webkit/glue/cpp_variant.cc b/webkit/glue/cpp_variant.cc
index a254669a2ecc056a7ecee405603de8b7c8b32592..bf995fc476a53843c7860c00acfb91dbbb3a891a 100644
--- a/webkit/glue/cpp_variant.cc
+++ b/webkit/glue/cpp_variant.cc
@@ -228,8 +228,8 @@ std::vector<std::wstring> CppVariant::ToStringVector() const {
length = NPVARIANT_TO_INT32(length_value);
WebBindings::releaseVariantValue(&length_value);
- // For sanity, only allow 100 items.
- length = std::min(100, length);
+ // For sanity, only allow 60000 items.
+ length = std::min(60000, length);
for (int i = 0; i < length; ++i) {
// Get each of the items.
std::string index = StringPrintf("%d", i);
« no previous file with comments | « chrome/browser/resources/options.html ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698